@@ -61,15 +61,16 @@ impl TestCgroup {
 
     fn create_file_with_content<P: AsRef<Path>>(&self, p: P, content: &[u8]) {
         let path = self.path().join(p);
-        let mut file = File::create(&path).expect(&format!("Failed to create {}", path.display()));
+        let mut file =
+            File::create(&path).unwrap_or_else(|_| panic!("Failed to create {}", path.display()));
         file.write_all(content)
-            .expect(&format!("Failed to write to {}", path.display()));
+            .unwrap_or_else(|_| panic!("Failed to write to {}", path.display()));
     }
 
     fn create_child<P: AsRef<Path>>(&self, p: P) {
         let path = self.path().join(p);
         std::fs::create_dir(&path)
-            .expect(&format!("Failed to create child cgroup {}", path.display()));
+            .unwrap_or_else(|_| panic!("Failed to create child cgroup {}", path.display()));
     }
 }
 
@@ -138,12 +139,15 @@ macro_rules! singleline_integer_or_max_test {
     };
 }
 
+singleline_integer_or_max_test!(read_pids_max, "pids.max");
+singleline_integer_or_max_test!(read_memory_min, "memory.min");
 singleline_integer_or_max_test!(read_memory_low, "memory.low");
 singleline_integer_or_max_test!(read_memory_high, "memory.high");
 singleline_integer_or_max_test!(read_memory_max, "memory.max");
 singleline_integer_or_max_test!(read_memory_swap_max, "memory.swap.max");
 singleline_integer_or_max_test!(read_memory_zswap_max, "memory.zswap.max");
 
+test_success!(read_pids_current, "pids.current", b"10000\n", 10000);
 test_success!(read_cpu_weight, "cpu.weight", b"10000\n", 10000);
 test_failure!(read_cpu_weight, "cpu.weight", b"5000000000\n");
 test_success!(
@@ -349,7 +353,7 @@ fn test_memory_stat_overflow() {
         .read_memory_stat()
         .expect("Failed to read memory.stat");
     assert_eq!(
-        val.slab.expect("Failed to populate slab field") as u64,
+        val.slab.expect("Failed to populate slab field"),
         14914318128160131214
     );
 }
@@ -432,7 +436,7 @@ fn test_cpu_stat_invalid_format() {
 #[test]
 fn test_io_stat_success() {
     let cgroup = TestCgroup::new();
-    cgroup.create_file_with_content("io.stat", b"253:0 rbytes=531 wbytes=162379 rios=61 wios=81 dbytes=0 dios=0\n13:0 rbytes=135 wbytes=162379 rios=61 wios=81 dbytes=0 dios=0 cost.usage=25 cost.wait=38 cost.indebt=64 cost.indelay=0\n");
+    cgroup.create_file_with_content("io.stat", b"7:0 \n253:0 rbytes=531 wbytes=162379 rios=61 wios=81 dbytes=0 dios=0\n13:0 rbytes=135 wbytes=162379 rios=61 wios=81 dbytes=0 dios=0 cost.usage=25 cost.wait=38 cost.indebt=64 cost.indelay=0\n");
 
     let cgroup_reader = cgroup.get_reader();
     let val = cgroup_reader
