@@ -1,5 +1,5 @@
 use serde::{
-    ser::{self, SerializeSeq, SerializeTuple},
+    ser::{self, SerializeMap, SerializeSeq, SerializeTuple},
     Serialize,
 };
 use std::{
@@ -326,21 +326,19 @@ where
     }
 
     fn serialize_struct(self, _name: &'static str, len: usize) -> Result<Self::SerializeStruct> {
-        if len == 0 {
-            return StructSerializer::unit(self).map(StructSeqSerializer::Struct);
-        }
-
         self.0
             .add_padding(self.0.signature.alignment(self.0.ctxt.format()))?;
         match &self.0.signature {
             Signature::Variant => StructSerializer::variant(self).map(StructSeqSerializer::Struct),
             Signature::Array(_) => self.serialize_seq(Some(len)).map(StructSeqSerializer::Seq),
+            Signature::U8 => StructSerializer::unit(self).map(StructSeqSerializer::Struct),
             Signature::Structure(_) => {
                 StructSerializer::structure(self).map(StructSeqSerializer::Struct)
             }
+            Signature::Dict { .. } => self.serialize_map(Some(len)).map(StructSeqSerializer::Map),
             _ => Err(Error::SignatureMismatch(
                 self.0.signature.clone(),
-                "a struct, array or variant".to_string(),
+                "a struct, array, u8 or variant".to_string(),
             )),
         }
     }
@@ -369,7 +367,7 @@ pub struct SeqSerializer<'ser, 'b, W> {
     array_signature: &'ser Signature,
 }
 
-impl<'ser, 'b, W> SeqSerializer<'ser, 'b, W>
+impl<W> SeqSerializer<'_, '_, W>
 where
     W: Write + Seek,
 {
@@ -401,7 +399,7 @@ where
     }
 }
 
-impl<'ser, 'b, W> ser::SerializeSeq for SeqSerializer<'ser, 'b, W>
+impl<W> ser::SerializeSeq for SeqSerializer<'_, '_, W>
 where
     W: Write + Seek,
 {
@@ -554,6 +552,7 @@ where
 pub enum StructSeqSerializer<'ser, 'b, W> {
     Struct(StructSerializer<'ser, 'b, W>),
     Seq(SeqSerializer<'ser, 'b, W>),
+    Map(MapSerializer<'ser, 'b, W>),
 }
 
 macro_rules! serialize_struct_anon_fields {
@@ -591,6 +590,7 @@ macro_rules! serialize_struct_anon_fields {
                 match self {
                     StructSeqSerializer::Struct(ser) => ser.$method(value),
                     StructSeqSerializer::Seq(ser) => ser.serialize_element(value),
+                    StructSeqSerializer::Map(_) => unreachable!(),
                 }
             }
 
@@ -598,6 +598,7 @@ macro_rules! serialize_struct_anon_fields {
                 match self {
                     StructSeqSerializer::Struct(ser) => ser.end_struct(),
                     StructSeqSerializer::Seq(ser) => ser.end_seq(),
+                    StructSeqSerializer::Map(_) => unreachable!(),
                 }
             }
         }
@@ -607,13 +608,13 @@ serialize_struct_anon_fields!(SerializeTuple serialize_element);
 serialize_struct_anon_fields!(SerializeTupleStruct serialize_field);
 serialize_struct_anon_fields!(SerializeTupleVariant serialize_field);
 
-pub(crate) struct MapSerializer<'ser, 'b, W> {
+pub struct MapSerializer<'ser, 'b, W> {
     seq: SeqSerializer<'ser, 'b, W>,
     key_signature: &'ser Signature,
     value_signature: &'ser Signature,
 }
 
-impl<'ser, 'b, W> ser::SerializeMap for MapSerializer<'ser, 'b, W>
+impl<W> SerializeMap for MapSerializer<'_, '_, W>
 where
     W: Write + Seek,
 {
@@ -680,6 +681,10 @@ macro_rules! serialize_struct_named_fields {
                 match self {
                     StructSeqSerializer::Struct(ser) => ser.serialize_field(key, value),
                     StructSeqSerializer::Seq(ser) => ser.serialize_element(value),
+                    StructSeqSerializer::Map(ser) => {
+                        ser.serialize_key(key)?;
+                        ser.serialize_value(value)
+                    }
                 }
             }
 
@@ -687,6 +692,7 @@ macro_rules! serialize_struct_named_fields {
                 match self {
                     StructSeqSerializer::Struct(ser) => ser.end_struct(),
                     StructSeqSerializer::Seq(ser) => ser.end_seq(),
+                    StructSeqSerializer::Map(ser) => ser.end(),
                 }
             }
         }
